.. DHCP anonymity profile documentation master file, created by
   sphinx-quickstart on Sat Jul 23 19:57:52 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dhcpcanon's documentation!
==================================================

Contents:

.. toctree::
   :maxdepth: 2

   about
   install
   download
   running
   todo
   contributing
   soa
   implementation
   integration
   api
   diagrams

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
